@@ -1,10 +1,10 @@
 package Net::DNS::Resolver::os2;
 
 #
-# $Id: os2.pm 1185 2014-04-03 09:21:21Z willem $
+# $Id: os2.pm 1235 2014-07-29 07:58:19Z willem $
 #
 use vars qw($VERSION);
-$VERSION = (qw$LastChangedRevision: 1185 $)[1];
+$VERSION = (qw$LastChangedRevision: 1235 $)[1];
 
 =head1 NAME
 
@@ -26,25 +26,24 @@ push( @config_path, $ENV{HOME} ) if exists $ENV{HOME};
 push( @config_path, '.' );
 
 
-sub init {
-	my ($class) = @_;
+sub _untaint { map defined && /^(.+)$/ ? $1 : (), @_; }
 
-	$class->read_config_file($resolv_conf) if -f $resolv_conf && -r _;
+
+sub init {
+	my $defaults = shift->defaults;
+
+	$defaults->read_config_file($resolv_conf) if -f $resolv_conf && -r _;
+
+	$defaults->domain( _untaint $defaults->domain );	# untaint config values
+	$defaults->searchlist( _untaint $defaults->searchlist );
+	$defaults->nameservers( _untaint $defaults->nameservers );
 
 	foreach my $dir (@config_path) {
 		my $file = "$dir/$dotfile";
-		$class->read_config_file($file) if -f $file && -r _ && -o _;
+		$defaults->read_config_file($file) if -f $file && -r _ && -o _;
 	}
 
-	$class->read_env;
-
-	my $defaults = $class->defaults;
-
-	if ( !$defaults->{domain} && @{$defaults->{searchlist}} ) {
-		$defaults->{domain} = $defaults->{searchlist}[0];
-	} elsif ( !@{$defaults->{searchlist}} && $defaults->{domain} ) {
-		$defaults->{searchlist} = [$defaults->{domain}];
-	}
+	$defaults->read_env;
 }
 
 
